==> xlniuxdata-vipgame-1.0.1-20150204.082012-17-sources.jar: com/xunlei/niux/data/vipgame/dto/GiftRecordDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordDTO {

    private Long recordId;
    private Long giftId;
    private String userId;
    private String gameId;
    private String serverId;
    private String serverName;
    private String roleId;
    private Double giftNum;
    private String mobile;
    private String giftStatus;
    private String actNo;
    private String thirdRecordId;
    private String failCause;
    private String recordTime;
    private String dealTime;
    private String expireDate;
    private String xunleiVipType;
    private Long parentRecordId;
    private Boolean isShow;
    private String showLocNo;
    private String serialNumber;
    private Boolean releaseStatus;
    private String releaseTime;


    private Integer goodId;

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }

    public Long getGiftId() {
        return giftId;
    }

    public void setGiftId(Long giftId) {
        this.giftId = giftId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getServerId() {
        return serverId;
    }

    public void setServerId(String serverId) {
        this.serverId = serverId;
    }

    public String getRoleId() {
        return roleId;
    }

    public void setRoleId(String roleId) {
        this.roleId = roleId;
    }

    public Double getGiftNum() {
        return giftNum;
    }

    public void setGiftNum(Double giftNum) {
        this.giftNum = giftNum;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getGiftStatus() {
        return giftStatus;
    }

    public void setGiftStatus(String giftStatus) {
        this.giftStatus = giftStatus;
    }

    public String getActNo() {
        return actNo;
    }

    public void setActNo(String actNo) {
        this.actNo = actNo;
    }

    public String getThirdRecordId() {
        return thirdRecordId;
    }

    public void setThirdRecordId(String thirdRecordId) {
        this.thirdRecordId = thirdRecordId;
    }

    public String getFailCause() {
        return failCause;
    }

    public void setFailCause(String failCause) {
        this.failCause = failCause;
    }

    public String getRecordTime() {
        return recordTime;
    }

    public void setRecordTime(String recordTime) {
        this.recordTime = recordTime;
    }

    public String getDealTime() {
        return dealTime;
    }

    public void setDealTime(String dealTime) {
        this.dealTime = dealTime;
    }

    public String getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(String expireDate) {
        this.expireDate = expireDate;
    }

    public String getXunleiVipType() {
        return xunleiVipType;
    }

    public void setXunleiVipType(String xunleiVipType) {
        this.xunleiVipType = xunleiVipType;
    }

    public Long getParentRecordId() {
        return parentRecordId;
    }

    public void setParentRecordId(Long parentRecordId) {
        this.parentRecordId = parentRecordId;
    }

    public Boolean getIsShow() {
        return isShow;
    }

    public void setIsShow(Boolean isShow) {
        this.isShow = isShow;
    }

    public String getShowLocNo() {
        return showLocNo;
    }

    public void setShowLocNo(String showLocNo) {
        this.showLocNo = showLocNo;
    }

    public String getSerialNumber() {
        return serialNumber;
    }

    public void setSerialNumber(String serialNumber) {
        this.serialNumber = serialNumber;
    }

    public Boolean getReleaseStatus() {
        return releaseStatus;
    }

    public void setReleaseStatus(Boolean releaseStatus) {
        this.releaseStatus = releaseStatus;
    }

    public String getReleaseTime() {
        return releaseTime;
    }

    public void setReleaseTime(String releaseTime) {
        this.releaseTime = releaseTime;
    }

    public Integer getGoodId() {
        return goodId;
    }

    public void setGoodId(Integer goodId) {
        this.goodId = goodId;
    }

    public String getServerName() {
        return serverName;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }
}

==> xlniuxdata-vipgame-1.0.65-20161019.034620-14-sources.jar: com/xunlei/niux/data/vipgame/dto/GiftRecordDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordDTO {

    private Long recordId;
    private Long giftId;
    private String userId;
    private String gameId;
    private String serverId;
    private String serverName;
    private String roleId;
    private Double giftNum;
    private String mobile;
    private String giftStatus;
    private String actNo;
    private String thirdRecordId;
    private String failCause;
    private String recordTime;
    private String dealTime;
    private String expireDate;
    private String xunleiVipType;
    private Long parentRecordId;
    private Boolean isShow;
    private String showLocNo;
    private String serialNumber;
    private Boolean releaseStatus;
    private String releaseTime;


    private Integer goodId;
    private String failureCause;

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }

    public Long getGiftId() {
        return giftId;
    }

    public void setGiftId(Long giftId) {
        this.giftId = giftId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getServerId() {
        return serverId;
    }

    public void setServerId(String serverId) {
        this.serverId = serverId;
    }

    public String getRoleId() {
        return roleId;
    }

    public void setRoleId(String roleId) {
        this.roleId = roleId;
    }

    public Double getGiftNum() {
        return giftNum;
    }

    public void setGiftNum(Double giftNum) {
        this.giftNum = giftNum;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getGiftStatus() {
        return giftStatus;
    }

    public void setGiftStatus(String giftStatus) {
        this.giftStatus = giftStatus;
    }

    public String getActNo() {
        return actNo;
    }

    public void setActNo(String actNo) {
        this.actNo = actNo;
    }

    public String getThirdRecordId() {
        return thirdRecordId;
    }

    public void setThirdRecordId(String thirdRecordId) {
        this.thirdRecordId = thirdRecordId;
    }

    public String getFailCause() {
        return failCause;
    }

    public void setFailCause(String failCause) {
        this.failCause = failCause;
    }

    public String getRecordTime() {
        return recordTime;
    }

    public void setRecordTime(String recordTime) {
        this.recordTime = recordTime;
    }

    public String getDealTime() {
        return dealTime;
    }

    public void setDealTime(String dealTime) {
        this.dealTime = dealTime;
    }

    public String getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(String expireDate) {
        this.expireDate = expireDate;
    }

    public String getXunleiVipType() {
        return xunleiVipType;
    }

    public void setXunleiVipType(String xunleiVipType) {
        this.xunleiVipType = xunleiVipType;
    }

    public Long getParentRecordId() {
        return parentRecordId;
    }

    public void setParentRecordId(Long parentRecordId) {
        this.parentRecordId = parentRecordId;
    }

    public Boolean getIsShow() {
        return isShow;
    }

    public void setIsShow(Boolean isShow) {
        this.isShow = isShow;
    }

    public String getShowLocNo() {
        return showLocNo;
    }

    public void setShowLocNo(String showLocNo) {
        this.showLocNo = showLocNo;
    }

    public String getSerialNumber() {
        return serialNumber;
    }

    public void setSerialNumber(String serialNumber) {
        this.serialNumber = serialNumber;
    }

    public Boolean getReleaseStatus() {
        return releaseStatus;
    }

    public void setReleaseStatus(Boolean releaseStatus) {
        this.releaseStatus = releaseStatus;
    }

    public String getReleaseTime() {
        return releaseTime;
    }

    public void setReleaseTime(String releaseTime) {
        this.releaseTime = releaseTime;
    }

    public Integer getGoodId() {
        return goodId;
    }

    public void setGoodId(Integer goodId) {
        this.goodId = goodId;
    }

    public String getServerName() {
        return serverName;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public String getFailureCause() {
        return failureCause;
    }

    public void setFailureCause(String failureCause) {
        this.failureCause = failureCause;
    }
}
